@@ -3,7 +3,7 @@ import nox
 nox.options.sessions = ["tests", "flake8", "mypy", "docs"]
 
 
-@nox.session(python=["3.6", "3.7", "3.8", "3.9", "3.10", "3.11"])
+@nox.session(python=["3.6", "3.7", "3.8", "3.9", "3.10", "3.11", "3.12"])
 def tests(session):
     session.install(".[test]")
     session.run("pytest")
